@@ -62,7 +62,7 @@ use PDepend\Source\ASTVisitor\ASTVisitor;
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  * @since 2.0.0
  */
-class ASTClassFqnPostfix extends ASTNode
+class ASTClassFqnPostfix extends AbstractASTNode
 {
     /**
      * Accept method of the visitor design pattern. This method will be called
