@@ -50,7 +50,7 @@ namespace PDepend\Source\AST;
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  * @since 0.9.12
  */
-class ASTClosure extends ASTNode implements ASTCallable
+class ASTClosure extends AbstractASTNode implements ASTCallable
 {
     /**
      * @return \PDepend\Source\AST\ASTType
