@@ -64,7 +64,7 @@ namespace PDepend\Source\AST;
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  * @since 0.9.6
  */
-class ASTPropertyPostfix extends ASTNode
+class ASTPropertyPostfix extends AbstractASTNode
 {
     /**
      * Accept method of the visitor design pattern. This method will be called
