@@ -284,6 +284,24 @@ abstract class AbstractASTCallable extends AbstractASTArtifact implements ASTCal
         return null;
     }
 
+    /**
+     * Tests if this callable has a return class and return <b>true</b> if it is
+     * configured.
+     *
+     * @return boolean
+     * @since 2.2.4
+     */
+    public function hasReturnClass()
+    {
+        if ($this->returnClassReference) {
+            return true;
+        }
+        if (($node = $this->getReturnType()) instanceof ASTClassOrInterfaceReference) {
+            return true;
+        }
+        return false;
+    }
+
     /**
      * @return \PDepend\Source\AST\ASTType
      */
@@ -476,7 +494,7 @@ abstract class AbstractASTCallable extends AbstractASTArtifact implements ASTCal
             'nodes',
             'startLine',
             'endLine',
-            'docComment',
+            'comment',
             'returnsReference',
             'returnClassReference',
             'exceptionClassReferences'
