@@ -99,20 +99,6 @@ abstract class AbstractASTType extends AbstractASTArtifact
      */
     protected $nodes = array();
 
-    /**
-     * The start line number of the class or interface declaration.
-     *
-     * @var integer
-     */
-    protected $startLine = 0;
-
-    /**
-     * The end line number of the class or interface declaration.
-     *
-     * @var integer
-     */
-    protected $endLine = 0;
-
     /**
      * Name of the parent namespace for this class or interface instance. Or
      * <b>NULL</b> when no namespace was specified.
@@ -134,7 +120,7 @@ abstract class AbstractASTType extends AbstractASTArtifact
      * @var   \PDepend\Source\AST\ASTMethod[]
      * @since 1.0.2
      */
-    private $methods = array();
+    protected $methods = array();
 
 
     /**
@@ -389,26 +375,6 @@ abstract class AbstractASTType extends AbstractASTArtifact
             ->store($this->id, $tokens);
     }
 
-    /**
-     * Returns the line number where the class or interface declaration starts.
-     *
-     * @return integer
-     */
-    public function getStartLine()
-    {
-        return $this->startLine;
-    }
-
-    /**
-     * Returns the line number where the class or interface declaration ends.
-     *
-     * @return integer
-     */
-    public function getEndLine()
-    {
-        return $this->endLine;
-    }
-
     /**
      * Returns the name of the parent namespace.
      *
@@ -502,7 +468,7 @@ abstract class AbstractASTType extends AbstractASTArtifact
         return array(
             'cache',
             'context',
-            'docComment',
+            'comment',
             'endLine',
             'modifiers',
             'name',
