@@ -46,6 +46,7 @@ use PDepend\Source\AST\AbstractASTClassOrInterface;
 use PDepend\Source\AST\ASTArtifactList;
 use PDepend\Source\AST\ASTClass;
 use PDepend\Source\AST\ASTClassOrInterfaceReference;
+use PDepend\Source\AST\ASTClassReference;
 use PDepend\Source\AST\ASTCompilationUnit;
 use PDepend\Source\AST\ASTFunction;
 use PDepend\Source\AST\ASTInterface;
@@ -109,7 +110,7 @@ class PHPBuilder implements Builder
     /**
      * All generated {@link \PDepend\Source\AST\ASTTrait} objects
      *
-     * @var array
+     * @var \PDepend\Source\AST\ASTTrait[]
      */
     private $traits = array();
 
@@ -151,7 +152,7 @@ class PHPBuilder implements Builder
     /**
      * Cache of all traits created during the regular parsing process.
      *
-     * @var array
+     * @var \PDepend\Source\AST\ASTTrait[]
      */
     private $frozenTraits = array();
 
@@ -246,7 +247,7 @@ class PHPBuilder implements Builder
      * @param string $qualifiedName The full qualified trait name.
      *
      * @return \PDepend\Source\AST\ASTTrait
-     * @since  1.0.0
+     * @since 1.0.0
      */
     public function buildTrait($qualifiedName)
     {
@@ -356,6 +357,16 @@ class PHPBuilder implements Builder
         return $class;
     }
 
+    /**
+     * Builds an anonymous class instance.
+     *
+     * @return \PDepend\Source\AST\ASTAnonymousClass
+     */
+    public function buildAnonymousClass()
+    {
+        return $this->buildAstNodeInstance('ASTAnonymousClass');
+    }
+
     /**
      * Builds a new code type reference instance.
      *
@@ -373,7 +384,7 @@ class PHPBuilder implements Builder
             'Creating: \PDepend\Source\AST\ASTClassReference(' . $qualifiedName . ')'
         );
 
-        return new \PDepend\Source\AST\ASTClassReference($this->context, $qualifiedName);
+        return new ASTClassReference($this->context, $qualifiedName);
     }
 
     /**
@@ -682,12 +693,13 @@ class PHPBuilder implements Builder
     /**
      * Builds a new expression node.
      *
+     * @param string $image
      * @return \PDepend\Source\AST\ASTExpression
-     * @since  0.9.8
+     * @since 0.9.8
      */
-    public function buildAstExpression()
+    public function buildAstExpression($image = null)
     {
-        return $this->buildAstNodeInstance('ASTExpression');
+        return $this->buildAstNodeInstance('ASTExpression', $image);
     }
 
     /**
@@ -894,6 +906,23 @@ class PHPBuilder implements Builder
         return $this->buildAstNodeInstance('ASTConditionalExpression', '?');
     }
 
+    /**
+     * Builds a new print-expression.
+     *
+     * <code>
+     * -------------
+     * print "qafoo";
+     * -------------
+     * </code>
+     *
+     * @return \PDepend\Source\AST\ASTConditionalExpression
+     * @since 2.3
+     */
+    public function buildAstPrintExpression()
+    {
+        return $this->buildAstNodeInstance('ASTPrintExpression', 'print');
+    }
+
     /**
      * Build a new shift left expression.
      *
@@ -2319,11 +2348,10 @@ class PHPBuilder implements Builder
     /**
      * Creates a {@link \PDepend\Source\AST\ASTNode} instance.
      *
-     * @param string $className Local name of the ast node class.
-     * @param string $image     Optional image for the created ast node.
-     *
+     * @param string $className
+     * @param string $image
      * @return \PDepend\Source\AST\ASTNode
-     * @since  0.9.12
+     * @since 0.9.12
      */
     private function buildAstNodeInstance($className, $image = null)
     {
